<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Bigquery;

class BiEngineStatistics extends \Google\Collection
{
  protected $collection_key = 'biEngineReasons';
  /**
   * @var string
   */
  public $accelerationMode;
  /**
   * @var string
   */
  public $biEngineMode;
  protected $biEngineReasonsType = BiEngineReason::class;
  protected $biEngineReasonsDataType = 'array';

  /**
   * @param string
   */
  public function setAccelerationMode($accelerationMode)
  {
    $this->accelerationMode = $accelerationMode;
  }
  /**
   * @return string
   */
  public function getAccelerationMode()
  {
    return $this->accelerationMode;
  }
  /**
   * @param string
   */
  public function setBiEngineMode($biEngineMode)
  {
    $this->biEngineMode = $biEngineMode;
  }
  /**
   * @return string
   */
  public function getBiEngineMode()
  {
    return $this->biEngineMode;
  }
  /**
   * @param BiEngineReason[]
   */
  public function setBiEngineReasons($biEngineReasons)
  {
    $this->biEngineReasons = $biEngineReasons;
  }
  /**
   * @return BiEngineReason[]
   */
  public function getBiEngineReasons()
  {
    return $this->biEngineReasons;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(BiEngineStatistics::class, 'Google_Service_Bigquery_BiEngineStatistics');
