<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

namespace Google\Service\Bigquery;

class ArimaFittingMetrics extends \Google\Model
{
  public $aic;
  public $logLikelihood;
  public $variance;

  public function setAic($aic)
  {
    $this->aic = $aic;
  }
  public function getAic()
  {
    return $this->aic;
  }
  public function setLogLikelihood($logLikelihood)
  {
    $this->logLikelihood = $logLikelihood;
  }
  public function getLogLikelihood()
  {
    return $this->logLikelihood;
  }
  public function setVariance($variance)
  {
    $this->variance = $variance;
  }
  public function getVariance()
  {
    return $this->variance;
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(ArimaFittingMetrics::class, 'Google_Service_Bigquery_ArimaFittingMetrics');
